# Unit Test Report: Python Unit Tester

# | Scenario | Fails (of 6) | Status
--- | --- | --- | ---
1 | Zero input groups, 1 of other entities where possible; active scenario; valid | 0 | SUCCESS
2 | Zero output groups, 1 of other entities where possible; active scenario; valid | 0 | SUCCESS
3 | Multiple entities; one inactive scenario; all valid | 0 | SUCCESS
4 | One input and output groups; multiple other entities; active scenarios; each type of invalid scenario | 0 | SUCCESS

# Test scenarios: 0 failed of 4: SUCCESS